==> plasma-widget-adjustableclock_2.5.1.orig.tar.bz2: adjustableclock-2.5.1/applet/AdjustableClock.h <==
/***********************************************************************************
* Adjustable Clock: Plasmoid to show date and time in adjustable format.
* Copyright (C) 2008 - 2009 Michal Dutkiewicz aka Emdek <emdeck@gmail.com>
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*
***********************************************************************************/

#ifndef ADJUSTABLECLOCK_HEADER
#define ADJUSTABLECLOCK_HEADER

#include "ui_appearance.h"
#include "ui_clipboard.h"

#include <QList>
#include <QTimer>
#include <QWebPage>
#include <QDateTime>

#include <KMenu>

#include <Plasma/Applet>
#include <Plasma/DataEngine>

#include <plasmaclock/clockapplet.h>

class AdjustableClock : public ClockApplet
{
    Q_OBJECT

public:
    AdjustableClock(QObject *parent, const QVariantList &args);

    void init();
    void paintInterface(QPainter *painter, const QStyleOptionGraphicsItem *option, const QRect &contentsRect);
    void createClockConfigurationInterface(KConfigDialog *parent);
    void connectSource(const QString &timezone);
    void setText(const QString &text);

protected:
    void constraintsEvent(Plasma::Constraints constraints);
    void mousePressEvent(QGraphicsSceneMouseEvent *event);
    void changeEngineTimezone(const QString &oldTimezone, const QString &newTimezone);
    QDateTime currentDateTime() const;
    QString formatDateTime(const QDateTime dateTime, const QString &format, bool clean = true) const;
    QList<QAction*> clipboardActions();
    QList<QAction*> contextualActions();

protected slots:
    void dataUpdated(const QString &name, const Plasma::DataEngine::Data &data);
    void clockConfigAccepted();
    void copyToClipboard();
    void insertPlaceholder(QAction *action);
    void loadItem(int index);
    void addItem(bool automatically = false);
    void removeItem();
    void updateControls();
    void toggleState();
    void selectColor();
    void selectFontSize(const QString &size);
    void selectFontFamily(const QFont &font);
    void setColor(const QString &color);
    void setFontSize(const QString &size);
    void setFontFamily(const QString &font);
    void contentsChanged();
    void formatChanged();
    void selectionChanged();
    void itemSelectionChanged();
    void insertRow();
    void deleteRow();
    void moveRow(bool up);
    void moveRowUp();
    void moveRowDown();
    void updateRow(int row, int column);
    void toolTipAboutToShow();
    void toolTipHidden();
    void copyToClipboard(QAction *action);
    void updateClipboardMenu();
    void updateToolTipContent();
    void updateSize();
    void updateTheme();
    void resetTimeFormat();

private:
    QWebPage m_page;
    QTimer *m_controlsTimer;
    QString m_timeFormat;
    QString m_toolTipFormat;
    QString m_fastCopyFormat;
    QString m_dateTimeString;
    QString m_timeZoneAbbreviation;
    QString m_timeZoneOffset;
    QString m_currentText;
    QStringList m_clipboardFormats;
    QStringList m_timeFormatStrings;
    QStringList m_timeFormatNames;
    QDateTime m_dateTime;
    QTime m_sunrise;
    QTime m_sunset;
    QAction *m_clipboardAction;
    KMenu *m_clipboardMenu;
    int m_fontSize;
    bool m_paintBackground;
    bool m_toolTipVisible;
    bool m_predefinedFormat;
    Ui::appearance m_appearanceUi;
    Ui::clipboard m_clipboardUi;
};

#endif

==> plasma-widget-adjustableclock_2.6.1.orig.tar.bz2: adjustableclock-2.6.1/applet/AdjustableClock.h <==
/***********************************************************************************
* Adjustable Clock: Plasmoid to show date and time in adjustable format.
* Copyright (C) 2008 - 2010 Michal Dutkiewicz aka Emdek <emdeck@gmail.com>
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*
***********************************************************************************/

#ifndef ADJUSTABLECLOCK_HEADER
#define ADJUSTABLECLOCK_HEADER

#include "ui_appearance.h"
#include "ui_clipboard.h"

#include <QList>
#include <QTimer>
#include <QWebPage>
#include <QDateTime>

#include <Plasma/Applet>
#include <Plasma/DataEngine>

#include <plasmaclock/clockapplet.h>


class AdjustableClock : public ClockApplet
{
    Q_OBJECT

public:
    AdjustableClock(QObject *parent, const QVariantList &args);

    void init();
    void paintInterface(QPainter *painter, const QStyleOptionGraphicsItem *option, const QRect &contentsRect);
    void createClockConfigurationInterface(KConfigDialog *parent);
    void connectSource(const QString &timezone);
    void setText(const QString &text);

protected:
    void constraintsEvent(Plasma::Constraints constraints);
    void mousePressEvent(QGraphicsSceneMouseEvent *event);
    void changeEngineTimezone(const QString &oldTimezone, const QString &newTimezone);
    QDateTime currentDateTime() const;
    QString formatDateTime(const QDateTime dateTime, const QString &format) const;
    QList<QAction*> contextualActions();

protected slots:
    void dataUpdated(const QString &name, const Plasma::DataEngine::Data &data);
    void clockConfigAccepted();
    void copyToClipboard();
    void insertPlaceholder(QAction *action);
    void loadFormat(int index);
    void addFormat(bool automatically = false);
    void removeFormat();
    void changeFormat();
    void updateControls();
    void toggleState();
    void selectColor();
    void selectFontSize(const QString &size);
    void selectFontFamily(const QFont &font);
    void setColor(const QString &color);
    void setFontSize(const QString &size);
    void setFontFamily(const QString &font);
    void selectionChanged();
    void itemSelectionChanged();
    void insertRow();
    void deleteRow();
    void moveRow(bool up);
    void moveRowUp();
    void moveRowDown();
    void updateRow(int row, int column);
    void toolTipAboutToShow();
    void toolTipHidden();
    void copyToClipboard(QAction *action);
    void updateClipboardMenu();
    void updateToolTipContent();
    void updateSize();
    void updateTheme();

private:
    QWebPage m_page;
    QTimer *m_controlsTimer;
    QString m_timeFormat;
    QString m_dateTimeString;
    QString m_timeZoneAbbreviation;
    QString m_timeZoneOffset;
    QString m_currentText;
    QStringList m_clipboardFormats;
    QStringList m_timeFormatStrings;
    QStringList m_timeFormatNames;
    QDateTime m_dateTime;
    QTime m_sunrise;
    QTime m_sunset;
    QAction *m_clipboardAction;
    int m_fontSize;
    Ui::appearance m_appearanceUi;
    Ui::clipboard m_clipboardUi;
};

#endif
